SoundManager = LCS.class({
	sources = {},
	fadeScheduler = Scheduler(),
	blabs = {}
})

function SoundManager:add_file(filename, type, loop)
	local new_source = love.audio.newSource(filename, type)
	if loop then new_source:setLooping(true) end
	self.sources[#self.sources + 1] = new_source
	return #self.sources
end

function SoundManager:add_blab(text, pitch, base, play_now)
	-- The default blabber sound
	base = base or "sfx/blabber1.ogg"
	table.insert(self.blabs, Blabber(text, pitch, base))
	if play_now then self:play_blab(#self.blabs) end
end

function SoundManager:play_blab(idx)
	self.blabs[idx]:play()
end


function SoundManager:play(src)
	self.sources[src]:play()
end

function SoundManager:pause(src)
	self.sources[src]:pause()
end

function SoundManager:stop(src)
	self.sources[src]:stop()
end

-- Deallocates the sound.
function SoundManager:destroy(src)
	self.sources[src] = nil
end

function SoundManager:set_volume(src, vol)
	self.sources[src]:setVolume(vol)
end

function SoundManager:fadeOut(src, duration, after_mode)
	-- if after mode is "stop", it means we want to call :stop().
	-- if it's "destroy", well, you know what to do.
	local after_callback
	if after_mode == "stop" then
		after_callback = function()
			self:stop(src)
		end
	end
	if after_mode == "destroy" then
		after_callback = function()
			self:destroy(src)
		end
	end
	self.fadeScheduler:add(animations.fadeSound(self.sources[src], -1), duration, nil, after_callback)
end

function SoundManager:update(dt)
	self.fadeScheduler:update(dt)
	for i, blabber in ipairs(self.blabs) do blabber:update(dt) end
end